==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: nl_NL\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: "Bel"

, "Calls"
: "Gesprekken"

, "Line"
: "Lijn"

, "Caller Id"
: "Beller ID"

, "Start"
: "Begin"

, "Connected"
: "Verbonden"

, "Disconnected"
: "Verbroken"

, "Duration"
: "Duur"

, "Ringing"
: "Gaat over"

, "Direction"
: "Richting"

, "Source"
: "Bron"

, "Destination"
: "Bestemming"

, "Phone"
: "Telefoon"

, "Phones"
: "Telefoons"

, "Settings"
: "Instellingen"

, "Lines"
: "Lijnen"

, "Description"
: "Beschrijving"

, "Number"
: "Nummer"

, "Cancel"
: "Geannuleerd"

, "Dial"
: "Bellen"

, "Error"
: "Fout"

, "Not possible to dial."
: "Bellen niet mogelijk"

, "Edit phone settings"
: "Wijzig telefoon gegevens"

, "Dial number"
: "Bel nummer"

, "Initiate a new outgoing call"
: "Nieuw uitgaand gesprek"

, "No phone selected"
: "Geen telefoon geselecteerd "

, "Please select the desired phone in the tree!"
: "Selecteer de gewenste telefoon in de lijst! "

, "Call contact"
: "Bel contact"

, "Work"
: "Werk"

, "Home"
: "Thuis"

, "Cell"
: "Mobiel"

, "Cell private"
: "Mobiel prive"

, "Incoming call"
: "Inkomend gesprek"

, "Outgoing call"
: "Uitgaand gesprek"

, "unknown number"
: "Onbekend nummer"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: "Bel deze week"

, "Incoming and outgoing calls of this week"
: "Inkomende en uitgaande gesprekken van deze week"

, "Calls last week"
: "Gesprekken vorige week"

, "Incoming and outgoing calls of last week"
: "Inkomende en uitgaande gesprekken van vorige week"

, "Calls this month"
: "Gesprekken deze maand"

, "Incoming and outgoing calls of this month"
: "Inkomende en uitgaande gesprekken van deze maand"

, "Calls last month"
: "Gesprekken vorige maand"

, "Incoming and outgoing calls of last month"
: "Inkomende en uitgaande gesprekken van vorige maand"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.08.8.tar.bz2: Phone/js/Phone-lang-nl_NL-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Dutch (Netherlands) (http://www.transifex.com/tine20/tine20/language/nl_NL/)\nLanguage: nl_NL\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Inkomend gesprek"

, "Outgoing call"
: "Uitgaand gesprek"

, "unknown number"
: "Onbekend nummer"

, "Phone"
: "Telefoon"

, "Line"
: "Lijn"

, "Number"
: "Nummer"

, "Cancel"
: "Geannuleerd"

, "Dial"
: "Bellen"

, "Error"
: "Fout"

, "Not possible to dial."
: "Bellen niet mogelijk"

, "Call contact"
: "Bel contact"

, "Work"
: "Werk"

, "Home"
: "Thuis"

, "Cell"
: "Mobiel"

, "Cell private"
: "Mobiel prive"

, "Edit phone settings"
: "Wijzig telefoon gegevens"

, "Dial number"
: "Bel nummer"

, "Initiate a new outgoing call"
: "Nieuw uitgaand gesprek"

, "Phones"
: "Telefoons"

, "No phone selected"
: "Geen telefoon geselecteerd "

, "Please select the desired phone in the tree!"
: "Selecteer de gewenste telefoon in de lijst! "

, "Calls this week"
: "Bel deze week"

, "Calls last week"
: "Gesprekken vorige week"

, "Calls this month"
: "Gesprekken deze maand"

, "Calls last month"
: "Gesprekken vorige maand"

, "Incoming and outgoing calls of this week"
: "Inkomende en uitgaande gesprekken van deze week"

, "Incoming and outgoing calls of last week"
: "Inkomende en uitgaande gesprekken van vorige week"

, "Incoming and outgoing calls of this month"
: "Inkomende en uitgaande gesprekken van deze maand"

, "Incoming and outgoing calls of last month"
: "Inkomende en uitgaande gesprekken van vorige maand"

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: "Bel"

, "Calls"
: "Gesprekken"

, "Caller Id"
: "Beller ID"

, "Start"
: "Begin"

, "Connected"
: "Verbonden"

, "Disconnected"
: "Verbroken"

, "Duration"
: "Duur"

, "Ringing"
: "Gaat over"

, "Direction"
: "Richting"

, "Source"
: "Bron"

, "Destination"
: "Bestemming"

, "resolved destination"
: ""

, "Settings"
: "Instellingen"

, "Lines"
: "Lijnen"

, "Description"
: "Beschrijving"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
